#ifndef NVIM_MOVE_H
#define NVIM_MOVE_H

#include <stdbool.h>
#include "nvim/buffer_defs.h"
#include "nvim/pos.h"

#ifdef INCLUDE_GENERATED_DECLARATIONS
# include "move.h.generated.h"
#endif
#endif  // NVIM_MOVE_H
